@@ -18,6 +18,7 @@ import zlib
 from django.contrib.auth.models import User
 from django.utils.encoding import smart_str
 
+from sentry.app import env
 from sentry.conf import settings
 from sentry.exceptions import InvalidInterface, InvalidData, InvalidTimestamp
 from sentry.models import Project, ProjectKey, TeamMember, Team
@@ -28,7 +29,7 @@ from sentry.utils.auth import parse_auth_header
 from sentry.utils.imports import import_string
 from sentry.utils.queue import maybe_delay
 
-logger = logging.getLogger('sentry.errors.coreapi')
+logger = logging.getLogger('sentry.coreapi.errors')
 
 MAX_CULPRIT_LENGTH = 200
 MAX_MESSAGE_LENGTH = 1000
@@ -283,24 +284,26 @@ def validate_data(project, data, client=None):
             process_data_timestamp(data)
         except InvalidTimestamp:
             # Log the error, remove the timestamp, and continue
-            logger.error('Client %r passed an invalid value for timestamp %r',
-                client or '<unknown client>',
-                data['timestamp'],
-            )
+            logger.info('Client %r passed an invalid value for timestamp %r',
+                client or '<unknown client>', data['timestamp'], extra={'request': env.request})
             del data['timestamp']
 
     if data.get('modules') and type(data['modules']) != dict:
         raise InvalidData('Invalid type for \'modules\': must be a mapping')
 
-    for k, v in data.items():
+    for k in data.keys():
         if k in RESERVED_FIELDS:
             continue
 
         if '.' not in k:
-            logger.error('Ignoring unknown attribute %r passed by client %r',
-                k,
-                client or '<unknown client>',
-            )
+            logger.info('Ignoring unknown attribute %r passed by client %r',
+                k, client or '<unknown client>', extra={'request': env.request})
+            del data[k]
+            continue
+
+        if not data[k]:
+            logger.info('Ignoring empty interface %r passed by client %r',
+                k, client or '<unknown client>', extra={'request': env.request})
             del data[k]
             continue
 
@@ -310,8 +313,11 @@ def validate_data(project, data, client=None):
             raise InvalidInterface('%r is not a valid interface name: %s' % (k, e))
 
         try:
-            data[k] = interface(**v).serialize()
+            data[k] = interface(**data[k]).serialize()
         except Exception, e:
+            logger.error('Client %r passed an invalid value for interface %r',
+                client or '<unknown client>',
+                interface, exc_info=True, extra={'request': env.request})
             raise InvalidData('Unable to validate interface, %r: %s' % (k, e))
 
     level = data.get('level') or settings.DEFAULT_LOG_LEVEL
