@@ -7,13 +7,6 @@
             '<div class="details">' + 
                 '<h3><a href="<%= permalink %>"><%= title %></a></h3>' + 
                 '<p class="message">' + 
-                    '<span class="tag tag-logger"><%= logger %></span>' + 
-                    '<% _.each(versions, function(version){ %> ' + 
-                        '<span class="tag tag-version"><%= version %></span>' + 
-                    '<% }) %>' + 
-                    '<% _.each(tags, function(tag){ %> ' + 
-                        '<span class="tag"><%= tag %></span>' + 
-                    '<% }) %>' + 
                     '<%= message %>' + 
                 '</p>' + 
                 '<div class="meta">' + 
@@ -22,19 +15,26 @@
                         '<span class="time-spent"><%= Math.round(timeSpent) %>ms</span>' + 
                     '<% } %>' + 
                     '<span class="tag tag-project"><%= project.name %></span>' + 
+                    '<span class="tag tag-logger"><%= logger %></span>' + 
+                    '<% _.each(versions, function(version){ %> ' + 
+                        '<span class="tag tag-version"><%= version %></span>' + 
+                    '<% }) %>' + 
+                    '<% _.each(tags, function(tag){ %> ' + 
+                        '<span class="tag"><%= tag %></span>' + 
+                    '<% }) %>' + 
                 '</div>' + 
                 '<span class="sparkline"></span>' + 
                 '<ul class="actions">' + 
                     '<% if (canResolve) { %>' + 
-                        '<li>' +
-                            '<% if (!isResolved) { %>' + 
-                                '<a href="#" data-action="resolve" title="Mark as Resolved">&#10003;</a>' + 
-                            '<% } else { %>' + 
-                                '<a href="#" class="checked" title="Already Resolved">&#10003;</a>' + 
-                            '<% } %>' + 
+                        '<li>' + 
+                            '<a href="#"<% if (!isResolved) { %> data-action="resolve" title="Mark as Resolved"<% } %> >' +
+                                '<i aria-hidden="true" class="icon-checkmark"></i>' +
+                            '</a>' + 
                         '</li>' + 
                         '<li>' + 
-                            '<a href="#" data-action="bookmark" class="bookmark<% if (isBookmarked) { %> checked<% } %>" title="Bookmark">&#9733;</a>' + 
+                            '<a href="#" data-action="bookmark" class="bookmark<% if (isBookmarked) { %> checked<% } %>" title="Bookmark">' +
+                                '<i aria-hidden="true" class="icon-star"></i>' +
+                            '</a>' + 
                         '</li>' + 
                     '<% } %>' + 
                 '</ul>' + 
